Sviluppatori

Riferimento API per sviluppatori

È necessaria una chiave API affinché le richieste vengano elaborate dal sistema. Una volta che un utente si registra, viene generata automaticamente una chiave API per questo utente.

Iniziare

È necessaria una chiave API affinché le richieste vengano elaborate dal sistema. Una volta che un utente si registra, viene generata automaticamente una chiave API per questo utente. La chiave API deve essere inviata con ogni richiesta (vedi esempio completo di seguito). Se la chiave API non viene inviata o è scaduta, si verificherà un errore. Assicurati di mantenere segreta la tua chiave API per prevenire abusi.

Autenticazione

Per autenticarti con il sistema API, devi inviare la tua chiave API come token di autorizzazione con ogni richiesta. Puoi vedere il codice di esempio di seguito.

curl --location --request POST 'https://linky.is/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Limite di tariffa

La nostra API ha un limitatore di velocità per salvaguardare da picchi di richieste per massimizzarne la stabilità. Il nostro limitatore di velocità è attualmente limitato a 30 richieste al 1 minuto. Tieni presente che la tariffa potrebbe cambiare in base al piano sottoscritto.

Insieme alla risposta verranno inviate diverse intestazioni che possono essere esaminate per determinare varie informazioni sulla richiesta.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Gestione della risposta

Tutte le risposte API vengono restituite in formato JSON per impostazione predefinita. Per convertirli in dati utilizzabili, sarà necessario utilizzare la funzione appropriata in base alla lingua. In PHP, la funzione json_decode() può essere utilizzata per convertire i dati in un oggetto (predefinito) o in un array (impostare il secondo parametro su true). È molto importante controllare la chiave di errore in quanto fornisce informazioni sull'eventuale presenza di un errore. Puoi anche controllare il codice dell'intestazione.

{
    "error": 1,
    "message": "An error occurred"
}

Ottieni account

GET https://linky.is/api/account

Per ottenere informazioni sull'account, puoi inviare una richiesta a questo endpoint che restituirà i dati sull'account.

curl --location --request GET 'https://linky.is/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "sample@domain.com",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Aggiorna account

PUT https://linky.is/api/account/update

Per aggiornare le informazioni sull'account, puoi inviare una richiesta a questo endpoint che aggiornerà i dati sull'account.

curl --location --request PUT 'https://linky.is/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "newemail@google.com",
    "password": "NewPassword1"
}'

Risposta del server

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Campagne

Elenco campagne

GET https://linky.is/api/campaigns?limit=2&page=1

Per ottenere le tue campagne tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Crea una campagna

POST https://linky.is/api/campaign/add

È possibile aggiungere una campagna utilizzando questo endpoint.

Parametro Descrizione
name (facoltativo) Nome della campagna
slug (opzionale) Slug del rotatore
public (facoltativo) Accesso
curl --location --request POST 'https://linky.is/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Risposta del server

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}

Assegna un collegamento a una campagna

POST https://linky.is/api/campaign/:campaignid/assign/:linkid

Un collegamento breve può essere assegnato a una campagna utilizzando questo endpoint. L'endpoint richiede l'ID campagna e l'ID collegamento breve.

curl --location --request POST 'https://linky.is/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Aggiorna campagna

PUT https://linky.is/api/campaign/:id/update

Per aggiornare una campagna, è necessario inviare dati validi in JSON tramite una richiesta PUT. I dati dovranno essere inviati come corpo grezzo della richiesta come indicato di seguito. L'esempio seguente mostra tutti i parametri che è possibile inviare ma non è necessario inviarli tutti (vedere la tabella per maggiori informazioni).

Parametro Descrizione
name (obbligatorio) Nome della campagna
slug (opzionale) Slug del rotatore
public (facoltativo) Accesso
curl --location --request PUT 'https://linky.is/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Risposta del server

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Elimina campagna

DELETE https://linky.is/api/campaign/:id/delete

Per eliminare una campagna è necessario inviare una richiesta DELETE.

curl --location --request DELETE 'https://linky.is/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Elenco canali

GET https://linky.is/api/channels?limit=2&page=1

Per ottenere i tuoi canali tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Elenca elementi del canale

GET https://linky.is/api/channel/:id?limit=1&page=1

Per ottenere elementi in canali selezionati tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/linky.is\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/linky.is\/mybio",
                "link": "https:\/\/linky.is\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Crea un canale

POST https://linky.is/api/channel/add

È possibile aggiungere un canale utilizzando questo endpoint.

Parametro Descrizione
name (obbligatorio) Nome del canale
description (facoltativo) Descrizione del canale
color (opzionale) Colore badge canale (HEX)
starred (facoltativo) Speciali o meno sul canale (vero o falso)
curl --location --request POST 'https://linky.is/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Risposta del server

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Assegna un elemento a un canale

POST https://linky.is/api/channel/:channelid/assign/:type/:itemid

Un elemento può essere assegnato a qualsiasi canale inviando una richiesta con l'ID del canale, il tipo di elemento (link, biografia o QR) e l'ID dell'elemento.

Parametro Descrizione
:channelid (obbligatorio) ID canale
:type (obbligatorio) link o bio o qr
:itemid (obbligatorio) ID elemento
curl --location --request POST 'https://linky.is/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Aggiorna canale

PUT https://linky.is/api/channel/:id/update

Per aggiornare un canale, è necessario inviare dati validi in JSON tramite una richiesta PUT. I dati dovranno essere inviati come corpo grezzo della richiesta come indicato di seguito. L'esempio seguente mostra tutti i parametri che è possibile inviare ma non è necessario inviarli tutti (vedere la tabella per maggiori informazioni).

Parametro Descrizione
name (facoltativo) Nome del canale
description (facoltativo) Descrizione del canale
color (opzionale) Colore badge canale (HEX)
starred (facoltativo) Speciali o meno sul canale (vero o falso)
curl --location --request PUT 'https://linky.is/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Risposta del server

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Elimina canale

DELETE https://linky.is/api/channel/:id/delete

Per eliminare un canale è necessario inviare una richiesta DELETE. Anche tutti gli elementi verranno annullati.

curl --location --request DELETE 'https://linky.is/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Codici QR

Elenca i codici QR

GET https://linky.is/api/qr?limit=2&page=1

Per ottenere i tuoi codici QR tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/linky.is\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/linky.is\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Ottieni un unico QR Code

GET https://linky.is/api/qr/:id

Per ottenere i dettagli per un singolo codice QR tramite l'API, puoi utilizzare questo endpoint.

curl --location --request GET 'https://linky.is/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/linky.is\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

Crea un codice QR

POST https://linky.is/api/qr/add

Per creare un QR Code è necessario inviare un dato valido in JSON tramite una richiesta POST. I dati dovranno essere inviati come corpo grezzo della richiesta come indicato di seguito. L'esempio seguente mostra tutti i parametri che è possibile inviare ma non è necessario inviarli tutti (vedere la tabella per maggiori informazioni).

Parametro Descrizione
type (richiesto) testo | vcard | collegamento | e-mail | telefono | sms | WiFi
data (obbligatorio) Dati da incorporare all'interno del codice QR. I dati possono essere stringhe o array a seconda del tipo
background (opzionale) Colore RGB ad es. RGB(255.255.255)
foreground (opzionale) Colore RGB ad es. RGB(0,0,0)
logo (facoltativo) Percorso del logo PNG o jpg
name (facoltativo) Nome del codice QR
curl --location --request POST 'https://linky.is/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Risposta del server

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/linky.is\/qr\/a58f79"
}

Aggiorna il codice QR

PUT https://linky.is/api/qr/:id/update

Per aggiornare un codice QR, devi inviare un dato valido in JSON tramite una richiesta PUT. I dati devono essere inviati come corpo grezzo della tua richiesta come mostrato di seguito. L'esempio seguente mostra tutti i parametri che puoi inviare ma non è necessario inviarli tutti (vedi tabella per maggiori informazioni).

Parametro Descrizione
data (obbligatorio) Dati da incorporare all'interno del codice QR. I dati possono essere stringhe o array a seconda del tipo
background (opzionale) Colore RGB ad es. RGB(255.255.255)
foreground (opzionale) Colore RGB ad es. RGB(0,0,0)
logo (facoltativo) Percorso del logo PNG o jpg
curl --location --request PUT 'https://linky.is/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Risposta del server

{
    "error": 0,
    "message": "QR has been updated successfully."
}

Elimina un codice QR

DELETE https://linky.is/api/qr/:id/delete

Per eliminare un codice QR, è necessario inviare una richiesta DELETE.

curl --location --request DELETE 'https://linky.is/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}

Domini personalizzati

Elenca domini con marchio

GET https://linky.is/api/domains?limit=2&page=1

Per ottenere i tuoi domini brandizzati tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedere la tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Crea un dominio brandizzato

POST https://linky.is/api/domain/add

È possibile aggiungere un dominio utilizzando questo endpoint. Assicurati che il dominio sia indirizzato correttamente al nostro server.

Parametro Descrizione
domain (obbligatorio) Dominio brandizzato, incluso http o https
redirectroot (facoltativo) Reindirizzamento root quando qualcuno visita il tuo dominio
redirect404 (facoltativo) Reindirizzamento 404 personalizzato
curl --location --request POST 'https://linky.is/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Risposta del server

{
    "error": 0,
    "id": 1
}

Aggiorna dominio

PUT https://linky.is/api/domain/:id/update

Per aggiornare un dominio brandizzato, è necessario inviare dati validi in JSON tramite una richiesta PUT. I dati dovranno essere inviati come corpo grezzo della richiesta come indicato di seguito. L'esempio seguente mostra tutti i parametri che è possibile inviare ma non è necessario inviarli tutti (vedere la tabella per maggiori informazioni).

Parametro Descrizione
redirectroot (facoltativo) Reindirizzamento root quando qualcuno visita il tuo dominio
redirect404 (facoltativo) Reindirizzamento 404 personalizzato
curl --location --request PUT 'https://linky.is/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Risposta del server

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Elimina dominio

DELETE https://linky.is/api/domain/:id/delete

Per eliminare un dominio è necessario inviare una richiesta DELETE.

curl --location --request DELETE 'https://linky.is/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

Overlay CTA

Elenca gli overlay CTA

GET https://linky.is/api/overlay?limit=2&page=1

Per ottenere sovrapposizioni CTA tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Pagina Splash personalizzata

Elenco Splash personalizzato

GET https://linky.is/api/splash?limit=2&page=1

To get Splash Pages via the API, you can use this endpoint. You can also filter data (See table for more info).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Elenca pixel

GET https://linky.is/api/pixels?limit=2&page=1

Per ottenere i codici pixel tramite l'API, puoi utilizzare questo endpoint. Puoi anche filtrare i dati (vedi tabella per maggiori informazioni).

Parametro Descrizione
limit (facoltativo) Risultato dei dati per pagina
page (facoltativo) Richiesta della pagina corrente
curl --location --request GET 'https://linky.is/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Crea un pixel

POST https://linky.is/api/pixel/add

È possibile creare un pixel utilizzando questo endpoint. Devi inviare il tipo di pixel e il tag.

Parametro Descrizione
type (required) gtmpixel | gapixel | fbpixel | adwordspixel | linkedinpixel | twitterpixel | adrollpixel | quorapixel | pinterest | bing | snapchat | reddit | tiktok
name (obbligatorio) Nome personalizzato per il tuo pixel
tag (obbligatorio) Il tag per il pixel
curl --location --request POST 'https://linky.is/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Risposta del server

{
    "error": 0,
    "id": 1
}

Aggiorna Pixel

PUT https://linky.is/api/pixel/:id/update

Per aggiornare un pixel, è necessario inviare dati validi in JSON tramite una richiesta PUT. I dati dovranno essere inviati come corpo grezzo della richiesta come indicato di seguito. L'esempio seguente mostra tutti i parametri che è possibile inviare ma non è necessario inviarli tutti (vedere la tabella per maggiori informazioni).

Parametro Descrizione
name (facoltativo) Nome personalizzato per il tuo pixel
tag (obbligatorio) Il tag per il pixel
curl --location --request PUT 'https://linky.is/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Risposta del server

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Elimina pixel

DELETE https://linky.is/api/pixel/:id/delete

Per eliminare un pixel è necessario inviare una richiesta DELETE.

curl --location --request DELETE 'https://linky.is/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Risposta del server

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}